linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* [PATCH v2 4/7] MIPS: BMIPS: Add BCM3368 support
@ 2016-08-03  9:58 Álvaro Fernández Rojas
  2016-08-04 17:47 ` Rob Herring
  0 siblings, 1 reply; 2+ messages in thread
From: Álvaro Fernández Rojas @ 2016-08-03  9:58 UTC (permalink / raw)
  To: linux-mips, linux-kernel, devicetree, ralf, f.fainelli, jogo,
	cernekee, robh, simon, john
  Cc: Álvaro Fernández Rojas

BCM3368 has a shared TLB which conflicts with current SMP support, so it must
be disabled for now.

Signed-off-by: Álvaro Fernández Rojas <noltari@gmail.com>
---
 Documentation/devicetree/bindings/mips/brcm/soc.txt | 2 +-
 arch/mips/bmips/setup.c                             | 3 ++-
 2 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/Documentation/devicetree/bindings/mips/brcm/soc.txt b/Documentation/devicetree/bindings/mips/brcm/soc.txt
index 4a7e030..65bc572 100644
--- a/Documentation/devicetree/bindings/mips/brcm/soc.txt
+++ b/Documentation/devicetree/bindings/mips/brcm/soc.txt
@@ -2,7 +2,7 @@
 
 Required properties:
 
-- compatible: "brcm,bcm3384", "brcm,bcm33843"
+- compatible: "brcm,bcm3368", "brcm,bcm3384", "brcm,bcm33843"
               "brcm,bcm3384-viper", "brcm,bcm33843-viper"
               "brcm,bcm6328", "brcm,bcm6358", "brcm,bcm6368",
               "brcm,bcm63168", "brcm,bcm63268",
diff --git a/arch/mips/bmips/setup.c b/arch/mips/bmips/setup.c
index f146d12..4fbd2f1 100644
--- a/arch/mips/bmips/setup.c
+++ b/arch/mips/bmips/setup.c
@@ -98,7 +98,7 @@ static void bcm6328_quirks(void)
 static void bcm6358_quirks(void)
 {
 	/*
 	 * BCM6358 needs special handling for its shared TLB, so
 	 * disable SMP for now
 	 */
 	bmips_smp_enabled = 0;
@@ -110,6 +110,7 @@ static void bcm6368_quirks(void)
 }
 
 static const struct bmips_quirk bmips_quirk_list[] = {
+	{ "brcm,bcm3368",		&bcm6358_quirks			},
 	{ "brcm,bcm3384-viper",		&bcm3384_viper_quirks		},
 	{ "brcm,bcm33843-viper",	&bcm3384_viper_quirks		},
 	{ "brcm,bcm6328",		&bcm6328_quirks			},
@@ -98,7 +98,7 @@ static void bcm6328_quirks(void)
 {
 	/*
-	 * BCM6358 needs special handling for its shared TLB, so
+	 * BCM3368/BCM6358 need special handling for their shared TLB, so
 	 * disable SMP for now
 	 */
-- 
2.1.4

^ permalink raw reply related	[flat|nested] 2+ messages in thread

* Re: [PATCH v2 4/7] MIPS: BMIPS: Add BCM3368 support
  2016-08-03  9:58 [PATCH v2 4/7] MIPS: BMIPS: Add BCM3368 support Álvaro Fernández Rojas
@ 2016-08-04 17:47 ` Rob Herring
  0 siblings, 0 replies; 2+ messages in thread
From: Rob Herring @ 2016-08-04 17:47 UTC (permalink / raw)
  To: Álvaro Fernández Rojas
  Cc: linux-mips, linux-kernel, devicetree, ralf, f.fainelli, jogo,
	cernekee, simon, john

On Wed, Aug 03, 2016 at 11:58:27AM +0200, Álvaro Fernández Rojas wrote:
> BCM3368 has a shared TLB which conflicts with current SMP support, so it must
> be disabled for now.
> 
> Signed-off-by: Álvaro Fernández Rojas <noltari@gmail.com>
> ---
>  Documentation/devicetree/bindings/mips/brcm/soc.txt | 2 +-
>  arch/mips/bmips/setup.c                             | 3 ++-
>  2 files changed, 3 insertions(+), 2 deletions(-)
> 
> diff --git a/Documentation/devicetree/bindings/mips/brcm/soc.txt b/Documentation/devicetree/bindings/mips/brcm/soc.txt
> index 4a7e030..65bc572 100644
> --- a/Documentation/devicetree/bindings/mips/brcm/soc.txt
> +++ b/Documentation/devicetree/bindings/mips/brcm/soc.txt
> @@ -2,7 +2,7 @@
>  
>  Required properties:
>  
> -- compatible: "brcm,bcm3384", "brcm,bcm33843"
> +- compatible: "brcm,bcm3368", "brcm,bcm3384", "brcm,bcm33843"

No need to respin just for this, but please make this one valid 
combination per line if you respin the series.

Acked-by: Rob Herring <robh@kernel.org>

>                "brcm,bcm3384-viper", "brcm,bcm33843-viper"
>                "brcm,bcm6328", "brcm,bcm6358", "brcm,bcm6368",
>                "brcm,bcm63168", "brcm,bcm63268",

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2016-08-04 17:47 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2016-08-03  9:58 [PATCH v2 4/7] MIPS: BMIPS: Add BCM3368 support Álvaro Fernández Rojas
2016-08-04 17:47 ` Rob Herring

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).